@@ -1,10 +1,6 @@
 package Log::Tree;
-{
-  $Log::Tree::VERSION = '0.15';
-}
-BEGIN {
-  $Log::Tree::AUTHORITY = 'cpan:TEX';
-}
+$Log::Tree::VERSION = '0.17';
+our $AUTHORITY = 'cpan:TEX';
 # ABSTRACT: lightweight but highly configurable logging class
 
 use 5.010_000;
@@ -21,7 +17,7 @@ use namespace::autoclean;
 use English qw( -no_match_vars );
 use Log::Dispatch;
 use Log::Dispatch::Screen;
-use Data::Tree;
+use Data::Tree '0.16';
 use IO::Interactive qw();
 
 has 'dispatcher' => (
@@ -80,6 +76,12 @@ has 'prefix' => (
     'default' => q{},
 );
 
+has 'suffix' => (
+    'is'      => 'rw',
+    'isa'     => 'Str',
+    'default' => q{},
+);
+
 has 'verbosity' => (
     'is'      => 'rw',
     'isa'     => 'Int',
@@ -331,7 +333,7 @@ sub _init_dispatcher {
     my $log = Log::Dispatch::->new();
 
     # only log to screen if running interactively
-    if(IO::Interactive::is_interactive()) {
+    if(IO::Interactive::is_interactive() || $ENV{'LOG_TREE_STDOUT'}) {
         $log->add(
             Log::Dispatch::Screen::->new(
                 name      => 'screen',
@@ -505,7 +507,14 @@ sub log {
         $mon++;
         $params_disp{'message'} = sprintf( '%04i.%02i.%02i-%02i:%02i:%02i', $year, $mon, $mday, $hour, $min, $sec ) . "\t" . $params_disp{'message'};
     }
+    
+    # append a user-supplied suffix
+    if ( $self->suffix() ) {
+        $params_disp{'message'} = $params_disp{'message'} . "\t" . $self->suffix();
+    }
+
     $params_disp{'message'} .= "\n";
+
     return $self->dispatcher()->log(%params_disp);
 }
 
@@ -544,7 +553,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
