@@ -1,10 +1,6 @@
 package Log::Tree::Logger;
-{
-  $Log::Tree::Logger::VERSION = '0.15';
-}
-BEGIN {
-  $Log::Tree::Logger::AUTHORITY = 'cpan:TEX';
-}
+$Log::Tree::Logger::VERSION = '0.17';
+our $AUTHORITY = 'cpan:TEX';
 # ABSTRACT: role providing a lazy initialized logger
 
 use 5.010_000;
@@ -53,7 +49,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
