@@ -1,10 +1,6 @@
 package Log::Tree::RequiredLogger;
-{
-  $Log::Tree::RequiredLogger::VERSION = '0.15';
-}
-BEGIN {
-  $Log::Tree::RequiredLogger::AUTHORITY = 'cpan:TEX';
-}
+$Log::Tree::RequiredLogger::VERSION = '0.17';
+our $AUTHORITY = 'cpan:TEX';
 # ABSTRACT: role providing a required logger attribute
 
 use 5.010_000;
@@ -43,7 +39,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
